diff --git a/glm/core/func_common.hpp b/glm/core/func_common.hpp
index 1c3295a7..7287ab96 100644
--- a/glm/core/func_common.hpp
+++ b/glm/core/func_common.hpp
@@ -213,22 +213,22 @@ namespace glm
typename genType::value_type const & minVal,
typename genType::value_type const & maxVal);
- //! @return If genTypeU is a floating scalar or vector:
- //! Returns x * (1.0 - a) + y * a, i.e., the linear blend of
- //! x and y using the floating-point value a.
- //! The value for a is not restricted to the range [0, 1].
- //!
- //! @return If genTypeU is a boolean scalar or vector:
- //! Selects which vector each returned component comes
- //! from. For a component of a that is false, the
- //! corresponding component of x is returned. For a
- //! component of a that is true, the corresponding
- //! component of y is returned. Components of x and y that
- //! are not selected are allowed to be invalid floating point
- //! values and will have no effect on the results. Thus, this
- //! provides different functionality than
- //! genType mix(genType x, genType y, genType(a))
- //! where a is a Boolean vector.
+ /// If genTypeU is a floating scalar or vector:
+ /// Returns x * (1.0 - a) + y * a, i.e., the linear blend of
+ /// x and y using the floating-point value a.
+ /// The value for a is not restricted to the range [0, 1].
+ ///
+ /// If genTypeU is a boolean scalar or vector:
+ /// Selects which vector each returned component comes
+ /// from. For a component of a that is false, the
+ /// corresponding component of x is returned. For a
+ /// component of a that is true, the corresponding
+ /// component of y is returned. Components of x and y that
+ /// are not selected are allowed to be invalid floating point
+ /// values and will have no effect on the results. Thus, this
+ /// provides different functionality than
+ /// genType mix(genType x, genType y, genType(a))
+ /// where a is a Boolean vector.
///
/// @see GLSL mix man page
/// @see GLSL 4.20.8 specification, section 8.3 Common Functions
diff --git a/glm/core/func_geometric.inl b/glm/core/func_geometric.inl
index 1923d05d..731b51c1 100644
--- a/glm/core/func_geometric.inl
+++ b/glm/core/func_geometric.inl
@@ -132,7 +132,6 @@ namespace glm
(
genType const & x,
genType const & y
-
)
{
GLM_STATIC_ASSERT(detail::type::is_float, "'dot' only accept floating-point inputs");
@@ -271,7 +270,7 @@ namespace glm
// reflect
template
- genType reflect
+ GLM_FUNC_QUALIFIER genType reflect
(
genType const & I,
genType const & N
diff --git a/glm/core/type_half.hpp b/glm/core/type_half.hpp
index 53551644..c1ab3446 100644
--- a/glm/core/type_half.hpp
+++ b/glm/core/type_half.hpp
@@ -37,8 +37,8 @@ namespace detail
{
typedef short hdata;
- float toFloat32(hdata value);
- hdata toFloat16(float const & value);
+ GLM_FUNC_DECL float toFloat32(hdata value);
+ GLM_FUNC_DECL hdata toFloat16(float const & value);
class half
{
@@ -72,42 +72,42 @@ namespace detail
hdata data;
};
- half operator+ (half const & s1, half const & s2);
+ GLM_FUNC_DECL half operator+ (half const & s1, half const & s2);
- half operator- (half const & s1, half const & s2);
+ GLM_FUNC_DECL half operator- (half const & s1, half const & s2);
- half operator* (half const & s1, half const & s2);
+ GLM_FUNC_DECL half operator* (half const & s1, half const & s2);
- half operator/ (half const & s1, half const & s2);
+ GLM_FUNC_DECL half operator/ (half const & s1, half const & s2);
// Unary constant operators
- half operator- (half const & s);
+ GLM_FUNC_DECL half operator- (half const & s);
- half operator-- (half const & s, int);
+ GLM_FUNC_DECL half operator-- (half const & s, int);
- half operator++ (half const & s, int);
+ GLM_FUNC_DECL half operator++ (half const & s, int);
- bool operator==(
+ GLM_FUNC_DECL bool operator==(
detail::half const & x,
detail::half const & y);
- bool operator!=(
+ GLM_FUNC_DECL bool operator!=(
detail::half const & x,
detail::half const & y);
- bool operator<(
+ GLM_FUNC_DECL bool operator<(
detail::half const & x,
detail::half const & y);
- bool operator<=(
+ GLM_FUNC_DECL bool operator<=(
detail::half const & x,
detail::half const & y);
- bool operator>(
+ GLM_FUNC_DECL bool operator>(
detail::half const & x,
detail::half const & y);
- bool operator>=(
+ GLM_FUNC_DECL bool operator>=(
detail::half const & x,
detail::half const & y);
diff --git a/glm/core/type_mat.hpp b/glm/core/type_mat.hpp
index cbf0c205..f55f3aca 100644
--- a/glm/core/type_mat.hpp
+++ b/glm/core/type_mat.hpp
@@ -34,40 +34,6 @@
namespace glm{
namespace detail
{
- //template
- //<
- // typename T,
- // template class C,
- // template class R
- //>
- //struct matType
- //{
- // enum ctor{null};
- // typedef T value_type;
- // typedef std::size_t size_type;
- // typedef C col_type;
- // typedef R row_type;
- // static size_type const col_size;
- // static size_type const row_size;
- //};
-
- //template
- //<
- // typename T,
- // template class C,
- // template class R
- //>
- //typename matType::size_type const
- //matType::col_size = matType::col_type::value_size;
-
- //template
- //<
- // typename T,
- // template class C,
- // template class R
- //>
- //typename matType::size_type const
- //matType::row_size = matType::row_type::value_size;
}//namespace detail
}//namespace glm
diff --git a/glm/core/type_mat3x2.hpp b/glm/core/type_mat3x2.hpp
index ad985b8e..22600c85 100644
--- a/glm/core/type_mat3x2.hpp
+++ b/glm/core/type_mat3x2.hpp
@@ -154,12 +154,12 @@ namespace detail
tmat3x2 operator+ (
tmat3x2 const & m,
typename tmat3x2::value_type const & s);
-
+
template
tmat3x2 operator+ (
tmat3x2 const & m1,
tmat3x2 const & m2);
-
+
template
tmat3x2 operator- (
tmat3x2 const & m,
diff --git a/glm/core/type_mat4x4.inl b/glm/core/type_mat4x4.inl
index e796506f..bed08758 100644
--- a/glm/core/type_mat4x4.inl
+++ b/glm/core/type_mat4x4.inl
@@ -191,7 +191,7 @@ namespace detail
X2 const & x2, Y2 const & y2, Z2 const & z2, W2 const & w2,
X3 const & x3, Y3 const & y3, Z3 const & z3, W3 const & w3,
X4 const & x4, Y4 const & y4, Z4 const & z4, W4 const & w4
- )
+ )
{
GLM_STATIC_ASSERT(detail::type::is_float || std::numeric_limits::is_integer, "*mat4x4 constructor only takes float and integer types, 1st parameter type invalid.");
GLM_STATIC_ASSERT(detail::type::is_float || std::numeric_limits::is_integer, "*mat4x4 constructor only takes float and integer types, 2nd parameter type invalid.");
diff --git a/readme.txt b/readme.txt
index a1bd95b1..73dc673c 100644
--- a/readme.txt
+++ b/readme.txt
@@ -44,7 +44,7 @@ GLM 0.9.5.X: 2013-XX-XX
- Added GTX_scalar_relational
================================================================================
-GLM 0.9.4.2: 2013-01-XX
+GLM 0.9.4.2: 2013-02-14
--------------------------------------------------------------------------------
- Fixed compAdd from GTX_component_wise
- Fixed SIMD support for Intel compiler on Windows
@@ -55,6 +55,8 @@ GLM 0.9.4.2: 2013-01-XX
- Fixed mix for vec4 SSE implementation
- Fixed 0x2013 dash character in comments that cause issue in Windows
Japanese mode
+- Fixed documentation warnings
+- Fixed CUDA warnings
================================================================================
GLM 0.9.4.1: 2012-12-22
diff --git a/glm/core/func_exponential.hpp b/glm/core/func_exponential.hpp
index 557ac175..20ea05b9 100644
--- a/glm/core/func_exponential.hpp
+++ b/glm/core/func_exponential.hpp
@@ -41,16 +41,16 @@ namespace glm
/// @addtogroup core_func_exponential
/// @{
/// Returns x raised to the y power.
///
/// @param x pow function is defined for input values of x defined in the range (inf-, inf+) in the limit of the type precision.
/// @param y
/// @tparam genType Floating-point scalar or vector types.
///
/// @see GLSL pow man page
/// @see GLSL 4.20.8 specification, section 8.2 Exponential Functions
template
- genType pow(genType const & x, genType const & y);
+ genType pow(genType const & base, genType const & exponent);
/// Returns the natural exponentiation of x, i.e., e^x.
///
@@ -41,16 +41,16 @@ namespace glm
/// @addtogroup core_func_exponential
/// @{
- /// Returns x raised to the y power.
+ /// Returns 'base' raised to the power 'exponent'.
///
@@ -41,16 +41,16 @@ namespace glm
///
- /// @param x pow function is defined for input values of x defined in the range (inf-, inf+) in the limit of the type precision.
- /// @param y
+ /// @param base Floating point value. pow function is defined for input values of x defined in the range (inf-, inf+) in the limit of the type precision.
+ /// @param exponent Floating point value representing the 'exponent'.
/// @tparam genType Floating-point scalar or vector types.
///